@@ -37,7 +37,7 @@
   info <- infoFund(rets, level = level, na.neg = na.neg)
   
   ## form output
-  out <- list(n = T, msharpe = info$msharpe, dmsharpe = as.vector(tmp$dmsharpe), 
+  out <- list(n = T, msharpe = info$msharpe, dmsharpe = -diff(info$msharpe), 
               tstat = as.vector(tmp$tstat), pval = as.vector(tmp$pval))
   return(out)
   
@@ -99,7 +99,7 @@
 #' 
 #' \code{pval}: pvalues of test of modified Sharpe ratios differences.
 #' @note Further details on the methdology with an application to the hedge
-#' fund industry is given in Ardia and Boudt (2016). 
+#' fund industry is given in Ardia and Boudt (2018). 
 #' 
 #' Some internal functions where adapted from Michael Wolf MATLAB code.
 #' 
@@ -112,10 +112,10 @@
 #' \emph{Finance Research Letters} \bold{13}, pp.97--104. 
 #' \doi{10.1016/j.frl.2015.02.008}
 #' 
-#' Ardia, D., Boudt, K. (2016).  
+#' Ardia, D., Boudt, K. (2018).  
 #' The Peer Ratios Performance of Hedge Funds. 
-#' \emph{Working paper}.
-#' \doi{10.2139/ssrn.2000901}
+#' \emph{Journal of Banking and Finance} \bold{87}, pp.351-.368.
+#' \doi{10.1016/j.jbankfin.2017.10.014}
 #' 
 #' Barras, L., Scaillet, O., Wermers, R. (2010).  
 #' False discoveries in mutual fund performance: Measuring luck in estimated alphas.  
